@@ -19,8 +19,8 @@
 /*******************************************************************************/
 /* Mark functions */
 /*******************************************************************************/
-void markRegion(int a, int b) { int i; for (i = MAX(a - base, 0); i <= MIN(b - base, nbBytes - 1); i++) markIt(i); }
-void unmarkRegion(int a, int b) { int i; for (i = MAX(a - base, 0); i <= MIN(b - base, nbBytes - 1); i++) unmarkIt(i); }
+void markRegion(INT a, INT b) { int i; for (i = MAX(a - base, 0); i <= MIN(b - base, nbBytes - 1); i++) markIt(i); }
+void unmarkRegion(INT a, INT b) { int i; for (i = MAX(a - base, 0); i <= MIN(b - base, nbBytes - 1); i++) unmarkIt(i); }
 void markSelectedRegion(void) { markRegion(mark_min, mark_max); }
 void unmarkAll(void) { unmarkRegion(base, base + nbBytes - 1); }
 void markIt(int i) { bufferAttr[i] |= MARKED; }
@@ -49,7 +49,7 @@ void copy_region(void)
 
   for (p = edited; p; p = p->next) {
     if (mark_min < p->base + p->size && p->base <= mark_max) {
-      int min = MIN(p->base, mark_min);
+      INT min = MIN(p->base, mark_min);
       memcpy(copyBuffer + p->base - min, 
 	     p->vals + mark_min - min,
 	     MIN(p->base + p->size, mark_max) - MAX(p->base, mark_min) + 1);
@@ -74,7 +74,7 @@ void yank_to_a_file(void)
 
   if (copyBuffer == NULL) { displayMessageAndWaitForKey("Nothing to paste"); return; }
 
-  if (!displayMessageAndGetString("File name (", &lastYankToAFile, tmp)) return;
+  if (!displayMessageAndGetString("File name (", &lastYankToAFile, tmp, sizeof(tmp))) return;
   
   if ((f = open(tmp, O_RDONLY)) != -1) {
     close(f);
@@ -102,7 +102,7 @@ void fill_with_string(void)
     displayTwoLineMessage("Hey, don't you think that's too big?!", "Really fill (Yes/No)");
     if (tolower(getch()) != 'y') return;
   }  
-  if (!displayMessageAndGetString(msg, last, tmp2)) return;
+  if (!displayMessageAndGetString(msg, last, tmp2, sizeof(tmp2))) return;
   l1 = mark_max - mark_min + 1;
   l2 = strlen(tmp2);
   if (hexOrAscii) {
